# RFC: Recommend and enable using Wild rather than Mold on Linux for local builds \(\#37717\) · gitcafe/zed

[View on GitCafe](https://git.cafe/gitcafe/zed/commit/10b99c6f55929a9f4a668fc4e81902b917e1c48a)

Repository: [gitcafe/zed](https://git.cafe/gitcafe/zed)

Visibility: public

Requested revision: 10b99c6f55929a9f4a668fc4e81902b917e1c48a

Requested commit: 10b99c6f55929a9f4a668fc4e81902b917e1c48a

Commit: 10b99c6f55929a9f4a668fc4e81902b917e1c48a

Tree: cd91285968042ebb1f25604db66b1eadbb076f8f

Author: Martin Pool

Committer: GitHub

## Message

```
RFC: Recommend and enable using Wild rather than Mold on Linux for local builds (#37717)

# Summary 

Today, Zed uses Mold on Linux, but Wild can be significantly faster. 

On my machine, Wild is 14% faster at a whole-tree clean build, 20%
faster on an incremental build with a minimal change, and makes no
measurable effect on runtime performance of tests.

However, Wild's page says it's not yet ready for production, so it seems
to early to switch for production and CI builds.

This PR keeps using Mold in CI and lets developers choose in their own
config what linker to use. (The downside of this is that after landing
this change, developers will have to do some local config or it will
fall back to the default linker which may be slower.)

[Wild 0.6 is out, and their announcement has some
benchmarks](https://davidlattimore.github.io/posts/2025/09/23/wild-update-0.6.0.html).

cc @davidlattimore from Wild, just fyi

# Tasks

- [x] Measure Wild build, incremental build, and runtime performance in
different scenarios
- [x] Remove the Linux linker config from `.cargo/config.toml` in the
tree
- [x] Test rope benchmarks etc
- [x] Set the linker to Mold in CI 
- [x] Add instructions to use Wild or Mold into `linux.md`
- [x] Add a script to download Wild
- [x] Measure binary size
- [x] Recommend Wild from `scripts/linux`

# Benchmarks 

| | wild 0.6 (rust 1.89) | mold 2.37.1 (1.89) | lld (rust 1.90) | wild
advantage |
| -- | -- | -- | -- | -- |
| clean workspace build | 176s | 184s | 182s | 5% faster than mold |
| nextest run workspace after build | 137s | 142s | 137s | in the noise?
|
| incremental rebuild | 3.9s | 5.0s | 6.6s | 22% faster than mold | 

I didn't observe any apparent significant change in runtime performance
or binary size, or in the in-tree microbenchmarks.

Release Notes:

- N/A

---------

Co-authored-by: Mateusz Mikuła <oss@mateuszmikula.dev>
```

## Parents

- [17dea24533affb0fcb35d96d07ab45d027b78ff1](https://git.cafe/gitcafe/zed/commit/17dea24533affb0fcb35d96d07ab45d027b78ff1?format=markdown)

[Source at this commit](https://git.cafe/gitcafe/zed/tree/10b99c6f55929a9f4a668fc4e81902b917e1c48a?format=markdown)
